function messages = simpleMailbox(username, message)
% simpleMailbox - Retrieve and send messages for use "username"
% 
% CALL:
%      messages = simpleMailbox(username) 
%      messages = simpleMailbox(username, message) 
% 
% INPUT:
%     username: <string>
%        identity of sender or receiver.
%     message: <any>
%         data to be sent. If not specified then retrieve messages for
%         "username" otherwise send message.
% 
% OUTPUT:
%     messages: <cell[]>
%         With all undelivered messages for "username"

persistent allMessages
assert(ischar(username),'First argument must be string identifying user')
messages={};
if nargin==2
    %send a message
    this.username = username;  %must be char string
    this.message  = {message}; %can be any type, use cell to avoid conflicts
    allMessages=cat(1,allMessages,this);
else
    %fetch all messages for username
    if isempty(allMessages)
        return  %no messages at all
    end
    tf=ismember({allMessages.username},username);
    messages=[allMessages(tf).message];  %deliver mail for username
    allMessages=allMessages(~tf);        %update mailbox
end
        
%Test sequence:
if 0
    simpleMailbox('userA','A1');
    simpleMailbox('userA','A2');
    simpleMailbox('userB','B1');
    
    rC=simpleMailbox('userC')
    rA=simpleMailbox('userA')
    rB=simpleMailbox('userB')
    
    %or, for remote evaluation:
    
    h = modelit.web.client.HttpRequest('GET','http://localhost:4444') 
    
    feval(h,@simpleMailbox,'userA','A1');
    feval(h,@simpleMailbox,'userA','A2');
    feval(h,@simpleMailbox,'userB','B1');
    
    rC = feval(h,@simpleMailbox,'userC')
    rA = feval(h,@simpleMailbox,'userA')
    rB = feval(h,@simpleMailbox,'userB')
end

